/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.adufour.vars.gui.swing;

import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.action.AbstractActionExt;
import org.jdesktop.swingx.action.ActionContainerFactory;
import org.jdesktop.swingx.table.ColumnControlButton;
import org.jdesktop.swingx.table.ColumnControlPopup;

import javax.swing.*;
import java.util.List;

/**
 * Persistent version of JXTable's column control button that keeps the pop-up open even after a
 * column is clicked (allowing multiple clicks at once). The pop-up will close if the
 * ColumnControlButton is pressed again. <br>
 * <br>
 * This code was adapted from the <a
 * href="http://www.coding-dude.com/wp/java/custom-columncontrolbutton-java-swing-jxtable/">
 * following page</a>.
 *
 * @author John Negoita
 * @author Alexandre Dufour
 */
public class PersistentColumnControlButton extends ColumnControlButton {
    public PersistentColumnControlButton(final JXTable table) {
        super(table);
    }

    @Override
    protected ColumnControlPopup createColumnControlPopup() {
        return new DefaultColumnControlPopup() {
            @Override
            public void addVisibilityActionItems(final List<? extends AbstractActionExt> actions) {
                final ActionContainerFactory factory = new ActionContainerFactory(null);
                for (final Action action : actions) {
                    final JMenuItem mi = factory.createMenuItem(action);
                    addItem(mi);
                }
            }
        };
    }
}